@@ -1,9 +1,9 @@
-from enum import Enum
+from enum import StrEnum
 
 __all__ = ["AudioFormat", "VideoFormat", "Quality"]
 
 
-class AudioFormat(Enum):
+class AudioFormat(StrEnum):
     MP3 = "mp3"
     M4A = "m4a"
     WAV = "wav"
@@ -11,18 +11,19 @@ class AudioFormat(Enum):
     OGG = "ogg"
 
 
-class VideoFormat(Enum):
+class VideoFormat(StrEnum):
     MP4 = "mp4"
     WEBM = "webm"
     MKV = "mkv"
     AVI = "avi"
 
 
-class Quality(Enum):
+class Quality(StrEnum):
     BEST = "best"
     WORST = "worst"
     AUDIO_ONLY = "bestaudio"
     VIDEO_ONLY = "bestvideo"
+    SD_480P = "480p"
     HD_720P = "720p"
     HD_1080P = "1080p"
     HD_1440P = "1440p"
